### soothsayer_utils
Utility functions for **[Soothsayer](http://www.github.com/jolespin/soothsayer)**

#### Dependencies:
Compatible for Python 2 and 3.

	pandas
	numpy
	tqdm >=4.19
	tzlocal
	biopython
	mmh3
	requests # Python 2/3 compatibility
	pathlib2 # Python 2/3 compatibility	
	bz2file # Python 2/3 compatibility

